@@ -1,4 +1,4 @@
-from typing import List, Optional, Dict, AnyStr
+from typing import List, Optional, Dict
 import subprocess
 
 
